#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import absolute_import

from .chromaticity_coordinates import COLOURCHECKERS
from .spds import COLOURCHECKER_INDEXES_TO_NAMES_MAPPING, COLOURCHECKERS_SPDS

__all__ = ['COLOURCHECKERS',
           'COLOURCHECKER_INDEXES_TO_NAMES_MAPPING',
           'COLOURCHECKERS_SPDS']
